@@ -12,21 +12,17 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-use ::std::fmt::Debug;
-
 #[derive(Clone, PartialEq, Debug)]
 pub struct True();
 #[derive(Clone, PartialEq, Debug)]
 pub struct False();
 
 pub trait BoolType {
-    type Choose<T: Clone + PartialEq + Debug, F: Clone + PartialEq + Debug>: Clone
-        + PartialEq
-        + Debug;
+    type Choose<T, F>;
 }
 impl BoolType for True {
-    type Choose<T: Clone + PartialEq + Debug, F: Clone + PartialEq + Debug> = T;
+    type Choose<T, F> = T;
 }
 impl BoolType for False {
-    type Choose<T: Clone + PartialEq + Debug, F: Clone + PartialEq + Debug> = F;
+    type Choose<T, F> = F;
 }
