@@ -12,10 +12,13 @@
 // See the License for the specific language governing permissions and
 // limitations under the License.
 
-pub mod builder;
+#[doc = include_str!("impls/builder.md")]
+pub mod builder {}
+pub mod bumpalo;
 pub mod either;
 pub mod empty;
 pub mod merged;
+pub mod option;
 pub mod simple;
-pub mod single_field;
-pub mod traits;
+#[doc = include_str!("impls/traits.md")]
+pub mod traits {}
